@@ -7,7 +7,7 @@
 #  define VTKFILTERSPARALLELVERDICT_NO_EXPORT
 #else
 #  ifndef VTKFILTERSPARALLELVERDICT_EXPORT
-#    ifdef vtkFiltersParallelVerdict_EXPORTS
+#    ifdef FiltersParallelVerdict_EXPORTS
         /* We are building this library */
 #      define VTKFILTERSPARALLELVERDICT_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,15 +23,25 @@
 
 #ifndef VTKFILTERSPARALLELVERDICT_DEPRECATED
 #  define VTKFILTERSPARALLELVERDICT_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKFILTERSPARALLELVERDICT_DEPRECATED_EXPORT VTKFILTERSPARALLELVERDICT_EXPORT __attribute__ ((__deprecated__))
-#  define VTKFILTERSPARALLELVERDICT_DEPRECATED_NO_EXPORT VTKFILTERSPARALLELVERDICT_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKFILTERSPARALLELVERDICT_NO_DEPRECATED
+#ifndef VTKFILTERSPARALLELVERDICT_DEPRECATED_EXPORT
+#  define VTKFILTERSPARALLELVERDICT_DEPRECATED_EXPORT VTKFILTERSPARALLELVERDICT_EXPORT VTKFILTERSPARALLELVERDICT_DEPRECATED
 #endif
 
-
-
+#ifndef VTKFILTERSPARALLELVERDICT_DEPRECATED_NO_EXPORT
+#  define VTKFILTERSPARALLELVERDICT_DEPRECATED_NO_EXPORT VTKFILTERSPARALLELVERDICT_NO_EXPORT VTKFILTERSPARALLELVERDICT_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKFILTERSPARALLELVERDICT_NO_DEPRECATED
+#    define VTKFILTERSPARALLELVERDICT_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkFiltersParallelVerdictModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKFILTERSPARALLELVERDICT_EXPORT_H */
