@@ -7,7 +7,7 @@
 #  define VTKRENDERINGVOLUMEAMR_NO_EXPORT
 #else
 #  ifndef VTKRENDERINGVOLUMEAMR_EXPORT
-#    ifdef vtkRenderingVolumeAMR_EXPORTS
+#    ifdef RenderingVolumeAMR_EXPORTS
         /* We are building this library */
 #      define VTKRENDERINGVOLUMEAMR_EXPORT __attribute__((visibility("default")))
 #    else
@@ -23,17 +23,25 @@
 
 #ifndef VTKRENDERINGVOLUMEAMR_DEPRECATED
 #  define VTKRENDERINGVOLUMEAMR_DEPRECATED __attribute__ ((__deprecated__))
-#  define VTKRENDERINGVOLUMEAMR_DEPRECATED_EXPORT VTKRENDERINGVOLUMEAMR_EXPORT __attribute__ ((__deprecated__))
-#  define VTKRENDERINGVOLUMEAMR_DEPRECATED_NO_EXPORT VTKRENDERINGVOLUMEAMR_NO_EXPORT __attribute__ ((__deprecated__))
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define VTKRENDERINGVOLUMEAMR_NO_DEPRECATED
+#ifndef VTKRENDERINGVOLUMEAMR_DEPRECATED_EXPORT
+#  define VTKRENDERINGVOLUMEAMR_DEPRECATED_EXPORT VTKRENDERINGVOLUMEAMR_EXPORT VTKRENDERINGVOLUMEAMR_DEPRECATED
 #endif
 
-/* AutoInit dependencies.  */
-#include "vtkRenderingVolumeModule.h"
-#include "vtkRenderingVolumeOpenGL2Module.h"
-
+#ifndef VTKRENDERINGVOLUMEAMR_DEPRECATED_NO_EXPORT
+#  define VTKRENDERINGVOLUMEAMR_DEPRECATED_NO_EXPORT VTKRENDERINGVOLUMEAMR_NO_EXPORT VTKRENDERINGVOLUMEAMR_DEPRECATED
 #endif
+
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef VTKRENDERINGVOLUMEAMR_NO_DEPRECATED
+#    define VTKRENDERINGVOLUMEAMR_NO_DEPRECATED
+#  endif
+#endif
+
+/* VTK-HeaderTest-Exclude: vtkRenderingVolumeAMRModule.h */
+
+/* Include ABI Namespace */
+#include "vtkABINamespace.h"
+
+#endif /* VTKRENDERINGVOLUMEAMR_EXPORT_H */
